@@ -38,6 +38,7 @@ from . import utils
 __author__ = 'dborowitz@google.com (Dave Borowitz)'
 
 BLOB_SHA = 'af431f20fc541ed6d5afede3e2dc7160f6f01f16'
+BLOB_NEW_CONTENT = b'foo bar\n'
 
 
 class BlobTest(utils.BareRepoTestCase):
@@ -52,6 +53,22 @@ class BlobTest(utils.BareRepoTestCase):
         self.assertEqual(b'a contents\n', blob.data)
         self.assertEqual(b'a contents\n', blob.read_raw())
 
+    def test_create_blob(self):
+        blob_oid = self.repo.create_blob(BLOB_NEW_CONTENT)
+        blob = self.repo[blob_oid]
+
+        self.assertTrue(isinstance(blob, pygit2.Blob))
+        self.assertEqual(pygit2.GIT_OBJ_BLOB, blob.type)
+
+        self.assertEqual(blob_oid, blob.oid)
+        self.assertEqual(
+          utils.gen_blob_sha1(BLOB_NEW_CONTENT),
+          utils.oid_to_hex(blob_oid)
+        )
+
+        self.assertEqual(BLOB_NEW_CONTENT, blob.data)
+        self.assertEqual(BLOB_NEW_CONTENT, blob.read_raw())
+
 
 if __name__ == '__main__':
     unittest.main()
